pub struct InvocationResourceLimits {
pub instructions: i64,
pub mem_bytes: i64,
pub disk_read_entries: u32,
pub write_entries: u32,
pub ledger_entries: u32,
pub disk_read_bytes: u32,
pub write_bytes: u32,
pub contract_events_size_bytes: u32,
pub max_contract_data_key_size_bytes: u32,
pub max_contract_data_entry_size_bytes: u32,
pub max_contract_code_entry_size_bytes: u32,
}Expand description
Resource limits that should be enforced during testing.
These should correspond to the respective network transaction-level limits.
Fields
instructions: i64Maximum Number of modelled CPU instructions.
mem_bytes: i64Maximum size of modelled memory in bytes.
disk_read_entries: u32Maximum number of entries that need to be read from disk.
This accounts for the total number of restored Soroban ledger entries and non-Soroban entries (such as ‘classic’ account balances).
write_entries: u32Maximum number of entries that need to be written to the ledger due to modification.
ledger_entries: u32Maximum number total ledger entries read and written (total size of the transaction footprint).
This is a sum of disk read entries, memory read entries and write entries.
disk_read_bytes: u32Maximum amount of bytes a transaction is allowed to read from disk.
write_bytes: u32Maximum total number of bytes that need to be written to the ledger.
contract_events_size_bytes: u32Maximum total size of the contract events emitted.
max_contract_data_key_size_bytes: u32Maximum size of a contract data key in bytes.
max_contract_data_entry_size_bytes: u32Maximum size of a contract data entry value in bytes.
max_contract_code_entry_size_bytes: u32Maximum size of a contract code entry in bytes.